==> hyades.source_1.2.1_20040126_0954.zip: org/eclipse/hyades/logging/adapter/Adapter.java <==
package org.eclipse.hyades.logging.adapter;

/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

import org.eclipse.hyades.logging.adapter.impl.Controller;
import org.eclipse.hyades.logging.adapter.util.Messages;
import org.eclipse.hyades.logging.adapter.internal.util.Paths;

/**
 * Adapter is a simple main entry point to run an adapter controller.
 */
public class Adapter {

    private Controller rootController = null;
    private String contextFile = null;
    private String componentFile = null;

    public void setContextConfigPath(String configFilePath) {
        contextFile = Paths.getConfigFileName(configFilePath);
    }

    public void setComponentConfigPath(String configFilePath) {
        componentFile = Paths.getConfigFileName(configFilePath);
    }

    public void start(boolean separateThread, boolean daemon) throws AdapterException {

        rootController = new Controller();

        if (componentFile == null) {
            componentFile = Messages.getString("HyadesGADefaultComponentConfigurationsFile"); //$NON-NLS-1$
        }

        if (contextFile == null) {
            contextFile = Messages.getString("HyadesGADefaultContextConfigurationFile"); //$NON-NLS-1$
        }

        rootController.setContextConfigPath(contextFile);
        rootController.setComponentConfigPath(componentFile);
        rootController.prepareAdapter();

        if (!separateThread) {
            rootController.run();

        }
        else {
            Thread serverThread = new Thread(rootController);
            serverThread.setDaemon(daemon);
            serverThread.start();
        }
    }

    public void stop() {
        if (rootController != null) {
            rootController.stop();
        }
    }

    public static void main(String[] args) {

        Adapter adapter = new Adapter();

        if (adapter.parseCommandLine(args)) {
            try {
                adapter.start(false, false);
            }
            catch (AdapterException e) {
                adapter.stop();
            }
        }
        else {
            System.out.println(Messages.getString("HyadesGACommand_line_usage"));
        }
    }

    private boolean parseCommandLine(String[] args) {

        if ((args != null) && (args.length > 0)) {

            String ccArgName = Messages.getString("HyadesGA-cc");
            String acArgName = Messages.getString("HyadesGA-ac");

            //Process all arguements:
            for (int i = 0; i < args.length; i++) {

                //If this is the -cc arguement, derive the context configuration:
                if (ccArgName.equalsIgnoreCase(args[i])) {

                    if ((++i < args.length) && (args[i] != null)) {
                        setContextConfigPath(Paths.getConfigFileName(args[i]));
                    }
					else{
						return false;
					}
                }

                //If this is the -ac arguement, derive the the component configuration:
                else if (acArgName.equalsIgnoreCase(args[i])) {

                    if ((++i < args.length) && (args[i] != null)) {
                        setComponentConfigPath(Paths.getConfigFileName(args[i]));
                    }
                    else{
                    	return false;
                    }
                }

                //If there is any other argument, fail:
                else {
                    return false;
                }
            }
        }

        return true;
    }
}

==> hyades.source_1.2.2_20040226_1349.zip: org/eclipse/hyades/logging/adapter/Adapter.java <==
package org.eclipse.hyades.logging.adapter;

/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

import org.eclipse.hyades.logging.adapter.impl.Controller;
import org.eclipse.hyades.logging.adapter.util.Messages;
import org.eclipse.hyades.logging.adapter.internal.util.Paths;

/**
 * Adapter is a simple main entry point to run an adapter controller.
 */
public class Adapter {

    private Controller rootController = null;
    private String contextFile = null;
    private String componentFile = null;

    public void setContextConfigPath(String configFilePath) {
        contextFile = Paths.getConfigFileName(configFilePath);
    }

    public void setComponentConfigPath(String configFilePath) {
        componentFile = Paths.getConfigFileName(configFilePath);
    }

    public void start(boolean separateThread, boolean daemon) throws AdapterException {

        rootController = new Controller();

        if (componentFile == null) {
            componentFile = Messages.getString("HyadesGADefaultComponentConfigurationsFile"); //$NON-NLS-1$
        }

        if (contextFile == null) {
            contextFile = Messages.getString("HyadesGADefaultContextConfigurationFile"); //$NON-NLS-1$
        }

        rootController.setContextConfigPath(contextFile);
        rootController.setComponentConfigPath(componentFile);
        
        /* try and prepare the adapter for running.  This may fail */
        rootController.prepareAdapter();

        if (!separateThread) {
            rootController.run();

        }
        else {
            Thread serverThread = new Thread(rootController);
            serverThread.setDaemon(daemon);
            serverThread.start();
        }
    }

    public void stop() {
        if (rootController != null) {
            rootController.stop();
        }
    }

    public static void main(String[] args) {

        Adapter adapter = new Adapter();

        if (adapter.parseCommandLine(args)) {
            try {
                adapter.start(false, false);
            }
            catch (AdapterException e) {
            	/* RKD:  If we get an exception at this point we likely do not have a valid configuration and hense
            	 * the log file is likely not flushed.  We will need to write this to stderr.
            	 */
            	System.err.println(Messages.getString("HyadesGAAdapterFatalError"));
            	System.err.println(e.getMessage());
                adapter.stop();
            }
        }
        else {
            System.out.println(Messages.getString("HyadesGACommand_line_usage"));
        }
    }

    private boolean parseCommandLine(String[] args) {

        if ((args != null) && (args.length > 0)) {

            String ccArgName = Messages.getString("HyadesGA-cc");
            String acArgName = Messages.getString("HyadesGA-ac");

            //Process all arguements:
            for (int i = 0; i < args.length; i++) {

                //If this is the -cc arguement, derive the context configuration:
                if (ccArgName.equalsIgnoreCase(args[i])) {

                    if ((++i < args.length) && (args[i] != null)) {
                        setContextConfigPath(Paths.getConfigFileName(args[i]));
                    }
					else{
						return false;
					}
                }

                //If this is the -ac arguement, derive the the component configuration:
                else if (acArgName.equalsIgnoreCase(args[i])) {

                    if ((++i < args.length) && (args[i] != null)) {
                        setComponentConfigPath(Paths.getConfigFileName(args[i]));
                    }
                    else{
                    	return false;
                    }
                }

                //If there is any other argument, fail:
                else {
                    return false;
                }
            }
        }

        return true;
    }
}
